ezprettyjson
============

| ez stands for easy.
| A convenient and flexible way to explore large json or dictionaries in
  the IPython notebook.
| Heavily inpired by `this javascript library`_

See the `example notebook`_

.. _this javascript library: http://caldwell.github.io/renderjson/
.. _example notebook: http://nbviewer.ipython.org/github/oscar6echo/ezprettyjson/blob/master/demo_ezprettyjson.ipynb